# Pixavi Scan Module SDK Documentation

## Overview
The Pixavi Scan Module SDK provides an Intent-based interface for Android applications. The interface allows apps to interact with the Scan Engine system service by using defined Intent actions and extras. Key functionalities include opening and releasing connections, triggering scanning actions, and receiving the scanned data.

## Actions
Your application should send broadcast Intents with the following action strings to communicate with the Scan Engine service:

- **com.pixavi.scanengine.action.OPEN**: Used to open a connection to the Scan Engine.
- **com.pixavi.scanengine.action.RELEASE**: Used to close the currently open connection to the Scan Engine.
- **com.pixavi.scanengine.action.TRIGGER_DOWN**: Used to start the scanning process.
- **com.pixavi.scanengine.action.TRIGGER_UP**: Used to stop the scanning process.

The Scan Engine service will send Intents to the package specified during OPEN with the following action strings to communicate with your application:

- **com.pixavi.scanengine.action.OPEN_SUCCESS**: Broadcasted when the connection to the Scan Engine has been successfully opened.
- **com.pixavi.scanengine.action.SCANNED_DATA_AVAILABLE**: Broadcasted when new scanned data is available.

## Extras
These are the additional data that can be attached to the Intent:

- **com.pixavi.scanengine.extra.CLIENT_PACKAGE**: This string should be set to the package name of your application when sending the OPEN action Intent. Any further Intents will only be sent to the specified package name, to protect against malicious applications listening to the events.
- **com.pixavi.scanengine.extra.VERSION**: Integer set by the Scan Engine service in the OPEN_SUCCESS broadcast Intent, indicating the version of the Scan Engine's Intent interface. Currently, the version is 1.
- **com.pixavi.scanengine.extra.EXTRA_SCANNED_DATA**: Byte array that will be set by the Scan Engine service in the SCANNED_DATA_AVAILABLE Intent, containing the scanned data in binary form.

## Usage
To open a connection to the Scan Engine, send a broadcast Intent with the OPEN action and CLIENT_PACKAGE extra. After opening successfully, text injection will be disabled, and the scanned data will only be delivered via the SCANNED_DATA_AVAILABLE Intent, to the specified CLIENT_PACKAGE.

```java
Intent intent = new Intent("com.pixavi.scanengine.action.OPEN");
intent.putExtra("com.pixavi.scanengine.extra.CLIENT_PACKAGE", getPackageName());
sendBroadcast(intent);
```

To handle the response from the Scan Engine, have a BroadcastReceiver registered for the OPEN_SUCCESS action:

```java
BroadcastReceiver openSuccessReceiver = new BroadcastReceiver() {
    @Override
    public void onReceive(Context context, Intent intent) {
        int version = intent.getIntExtra("com.pixavi.scanengine.extra.VERSION", -1);
        // Handle the received version
    }
};
IntentFilter filter = new IntentFilter("com.pixavi.scanengine.action.OPEN_SUCCESS");
registerReceiver(openSuccessReceiver, filter);
```

Send other broadcast Intents with the appropriate actions to control the Scan Engine. Listen for the SCANNED_DATA_AVAILABLE broadcast to receive the scanned data.

When you no longer need the connection to the Scan Engine, send a broadcast with the RELEASE action, to free up Scan Engine. This will re-enable text injection, and the scanned data will no longer be delivered via the SCANNED_DATA_AVAILABLE Intent.

```java
sendBroadcast(new Intent("com.pixavi.scanengine.action.RELEASE"));
```

## Error Handling
The Scan Engine service uses Android's logging system for error reporting. You can view the log messages by filtering the log with the tag "ScanEngine-IntentInterface", or just "ScanEngine" to see additional logs.
