package com.pixavi.scanengine.sdkdemo;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.widget.Button;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import java.util.Arrays;

public class MainActivity extends AppCompatActivity {
    public static final String SCAN_ENGINE_ACTION_OPEN = "com.pixavi.scanengine.action.OPEN";
    public static final String SCAN_ENGINE_ACTION_RELEASE = "com.pixavi.scanengine.action.RELEASE";
    public static final String SCAN_ENGINE_ACTION_TRIGGER_DOWN = "com.pixavi.scanengine.action.TRIGGER_DOWN";
    public static final String SCAN_ENGINE_ACTION_TRIGGER_UP = "com.pixavi.scanengine.action.TRIGGER_UP";

    public static final String SCAN_ENGINE_ACTION_OPEN_SUCCESS = "com.pixavi.scanengine.action.OPEN_SUCCESS";
    public static final String SCAN_ENGINE_ACTION_SCANNED_DATA_AVAILABLE = "com.pixavi.scanengine.action.SCANNED_DATA_AVAILABLE";

    public static final String SCAN_ENGINE_EXTRA_CLIENT_PACKAGE = "com.pixavi.scanengine.extra.CLIENT_PACKAGE";
    public static final String SCAN_ENGINE_EXTRA_VERSION = "com.pixavi.scanengine.extra.VERSION";
    public static final String SCAN_ENGINE_EXTRA_SCANNED_DATA = "com.pixavi.scanengine.extra.EXTRA_SCANNED_DATA";

    private TextView txtStatus;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Link elements from the XML layout
        Button btnOpen = findViewById(R.id.btnOpen);
        Button btnRelease = findViewById(R.id.btnRelease);
        Button btnTriggerDown = findViewById(R.id.btnTriggerDown);
        Button btnTriggerUp = findViewById(R.id.btnTriggerUp);
        txtStatus = findViewById(R.id.txtStatus);

        txtStatus.setMovementMethod(new ScrollingMovementMethod());

        // Set onClick listeners for buttons
        btnOpen.setOnClickListener(v -> sendIntent(SCAN_ENGINE_ACTION_OPEN));
        btnRelease.setOnClickListener(v -> sendIntent(SCAN_ENGINE_ACTION_RELEASE));
        btnTriggerDown.setOnClickListener(v -> sendIntent(SCAN_ENGINE_ACTION_TRIGGER_DOWN));
        btnTriggerUp.setOnClickListener(v -> sendIntent(SCAN_ENGINE_ACTION_TRIGGER_UP));

        // Register for broadcasts from ScanEngine
        IntentFilter filter = new IntentFilter();
        filter.addAction(SCAN_ENGINE_ACTION_OPEN_SUCCESS);
        filter.addAction(SCAN_ENGINE_ACTION_SCANNED_DATA_AVAILABLE);
        registerReceiver(scanEngineReceiver, filter);
    }

    private void sendIntent(String action) {
        log("Sending intent: " + action + "\n");

        Intent intent = new Intent(action);
        // Only really needed for SCAN_ENGINE_ACTION_OPEN, but sending it every time does no harm
        intent.putExtra(SCAN_ENGINE_EXTRA_CLIENT_PACKAGE, getPackageName());
        sendBroadcast(intent);
    }

    private void log(String msg) {
        txtStatus.append(msg + "\n");
    }

    // Define a BroadcastReceiver to handle broadcasts from ScanEngine
    private final BroadcastReceiver scanEngineReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();

            if (action == null) return;

            log("Received intent: " + action);

            switch (action) {
                case SCAN_ENGINE_ACTION_OPEN_SUCCESS:
                    log("Scan Engine opened successfully");
                    log("Interface version: "
                        + intent.getIntExtra(SCAN_ENGINE_EXTRA_VERSION, 0));
                    log("\n");
                    break;
                case SCAN_ENGINE_ACTION_SCANNED_DATA_AVAILABLE:
                    byte[] scannedData = intent.getByteArrayExtra(SCAN_ENGINE_EXTRA_SCANNED_DATA);
                    log("Received scanned data");
                    log("Binary: " + Arrays.toString(scannedData));
                    log("UTF-8: " + new String(scannedData));
                    log("\n");
                    break;
            }
        }
    };

    @Override
    protected void onDestroy() {
        super.onDestroy();
        // Unregister the receiver when the activity is destroyed.
        unregisterReceiver(scanEngineReceiver);
    }
}
